@@ -10,7 +10,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = ( );
 @EXPORT = qw( );
-$VERSION = '0.4';
+$VERSION = '0.5';
 $DICTDIR = '/usr/local/wordnet';
 $DELIM = '||';
 $SUBDELIM = '|';
@@ -29,6 +29,7 @@ Lingua::Wordnet - Perl extension for accessing and manipulating Wordnet database
   $synset2 = $wn->lookup_synset("small","a",1);
   $synset->add_attributes($synset2);
   $synset->write();
+  print $synset, "\n";
   $wn->close();
 
 =head1 DESCRIPTION
@@ -58,11 +59,6 @@ With that said, there are actually two modules. Lingua::Wordnet impersonates the
 Creates and assigns a new object of class Lingua::Wordnet. DATA_DIR is optional, and indicates the location of the index and data files. 
 
 
-=item $wn->overview(TEXT)
-
-Returns a string containing an overview of TEXT in all parts of speech.
-
-
 =item $wn->unlock()
 
 Allows files to be written to when data is added/edited/deleted. 
@@ -112,6 +108,11 @@ Returns an integer of the familiarity/polysemy count for WORD in POS. Given a th
 Returns a form of WORD in POS as found in the Wordnet morph files. The synset_lookup() functions performs morphological conversion automatically, so a call to morph() is not required.
 
 
+=item $synset->overview()
+
+Returns the terms and gloss for the synset in a format for printing. This method is also used to overload a print performed on the synset. Note that this is different from the "overview" parameter of the 'wn' executable, since it only returns information about the current synset.
+
+
 =item $synset->write()
 
 Writes any changes made to $synset to the database and updates all affected synset data and indexes. If $synset passes out of scope before write() is called, the changes are lost.
@@ -341,9 +342,7 @@ Clean up code, put references where beneficial.
 
 =head1 AUTHOR
 
-Copyright (C)2000, Daniel Brian.
-
-D. Brian, dbrian@brians.org.
+Dan Brian <dbrian@brians.org>
 
 =head1 SEE ALSO
 
@@ -395,11 +394,6 @@ sub close {
     $self->DESTROY();
 }
 
-# Anybody want to write an overview()? Please send it to me.
-sub overview {
-
-}
-
 sub familiarity {
     my $self = shift;
     my ($word,$pos) = @_;
@@ -562,6 +556,8 @@ my @vrbsents = (
 
 package Lingua::Wordnet::Synset;
 
+use overload qw("") => overview;
+
 sub new {
     my $class = shift;
     my ($wn,$offset,$pos,$word) = @_;
@@ -591,6 +587,15 @@ sub new {
     return $self;
 }
 
+sub overview {
+    my $self  = shift;
+    my @wordlist = $self->words;
+    my $words = join ", ", @wordlist;
+    $words =~ s/\%\d//g;
+    $words =~ s/\_/ /g;
+    return "$words -- (" . $self->gloss . ")";
+}
+
 # write
 sub write {
     my $self = shift;
